aboutsummaryrefslogtreecommitdiff
path: root/c/layout.h
diff options
context:
space:
mode:
Diffstat (limited to 'c/layout.h')
-rw-r--r--c/layout.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/c/layout.h b/c/layout.h
index 3c616b7..cbdcac7 100644
--- a/c/layout.h
+++ b/c/layout.h
@@ -12,14 +12,14 @@
void UpdateLayout(int w = 0, int h = 0);
/* Dragger objects implement draggable portions of the client area,
* such as the split between two list views. HandleDown and HandleMove
* are called by relevant window procedures upon WM_(NC)LBUTTONDOWN
* and WM_SETCURSOR. */
struct Dragger
{
- bool HandleDown();
- bool HandleMove();
+ bool HandleLButtonDown();
+ bool HandleSetCursor();
protected:
bool IsDown();
bool IsDouble();
@@ -63,7 +63,7 @@ inline bool Dragger::IsDown()
return GetKeyState(VK_LBUTTON) & 0x8000;
}
-inline bool Dragger::HandleDown()
+inline bool Dragger::HandleLButtonDown()
{
extern HWND g_hWnd;
POINT pt;
@@ -79,7 +79,7 @@ inline bool Dragger::HandleDown()
return m_bActive;
}
-inline bool Dragger::HandleMove()
+inline bool Dragger::HandleSetCursor()
{
extern HWND g_hWnd;
POINT pt;
@@ -12,14 +12,14 @@
void UpdateLayout(int w = 0, int h = 0);
/* Dragger objects implement draggable portions of the client area,
- * such as the split between two list views. HandleDown and HandleMove
- * are called by relevant window procedures upon WM_(NC)LBUTTONDOWN
- * and WM_SETCURSOR. */
+ * such as the split between two list views. HandleLButtonDown and
+ * HandleSetCursor are called by relevant window procedures upon
+ * WM_(NC)LBUTTONDOWN and WM_SETCURSOR. */
struct Dragger
{